Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1545)

Unified Diff: chrome/browser/instant/instant_client.h

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Added test Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_client.h
diff --git a/chrome/browser/instant/instant_client.h b/chrome/browser/instant/instant_client.h
index dffdc6b085f9c84c392a7aa82d3eef038e9b9b51..22cec8a203edbd347d4138283165af2640fb3801 100644
--- a/chrome/browser/instant/instant_client.h
+++ b/chrome/browser/instant/instant_client.h
@@ -104,8 +104,8 @@ class InstantClient : public content::WebContentsObserver {
// by the omnibox dropdown.
void SetPopupBounds(const gfx::Rect& bounds);
- // Tells the page what size start and end margins to use.
- void SetMarginSize(const int start, const int end);
+ // Tells the page the start-edge margin size and width to use.
+ void SetStartMarginAndWidth(int margin, int width);
// Tells the page about the font information.
void InitializeFonts();
« no previous file with comments | « no previous file | chrome/browser/instant/instant_client.cc » ('j') | chrome/browser/instant/instant_extended_browsertest.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698